'use strict';

const queryCore = require('@tanstack/query-core');

function subscribeQueryCallbacks({
  queryClient,
  queryKey,
  onSuccess,
  onError,
  onSettled
}) {
  if (!onSuccess && !onError && !onSettled)
    return noop;
  const cache = queryClient.getQueryCache();
  const unsubscribe = cache.subscribe((event) => {
    if (event.type !== "updated")
      return;
    if (!queryCore.matchQuery({ queryKey, exact: true }, event.query))
      return;
    switch (event.action.type) {
      case "success": {
        if (!event.action.manual) {
          onSuccess?.(event.action.data);
          onSettled?.(event.action.data, null);
        }
        break;
      }
      case "error": {
        if (!queryCore.isCancelledError(event.action.error)) {
          onError?.(event.action.error);
          onSettled?.(void 0, event.action.error);
        }
        break;
      }
    }
  });
  return unsubscribe;
}
function noop() {
}

exports.subscribeQueryCallbacks = subscribeQueryCallbacks;
