import { useQueryClient } from '@tanstack/vue-query';
import { inject, watch, unref } from 'vue-demi';
import { subscribeQueryCallbacks } from '../core/index.mjs';
import '@tanstack/query-core';

function useQueryCallbacks(props) {
  const queryClient = props.queryClient ?? (props.queryClientKey ? inject(props.queryClientKey, void 0) : void 0) ?? useQueryClient(props.queryClientId);
  watch(
    () => unref(props.queryKey),
    (queryKey, _oldVal, onCleanup) => {
      const unsubscribe = subscribeQueryCallbacks({
        queryClient,
        queryKey,
        onSuccess: props.onSuccess,
        onError: props.onError,
        onSettled: props.onSettled
      });
      onCleanup(() => {
        unsubscribe();
      });
    },
    { immediate: true }
  );
}

export { useQueryCallbacks };
